Title: [199125] trunk/Source/_javascript_Core
Revision
199125
Author
[email protected]
Date
2016-04-06 17:13:51 -0700 (Wed, 06 Apr 2016)

Log Message

Unreviewed, rolling in r199016.
https://bugs.webkit.org/show_bug.cgi?id=156140

It might work this time without regression because 16kB aligned requests
now take the allocation fast path.

Restored changeset:

CopiedBlock should be 16kB
https://bugs.webkit.org/show_bug.cgi?id=156168
http://trac.webkit.org/changeset/199016

Modified Paths

Diff

Modified: trunk/Source/_javascript_Core/ChangeLog (199124 => 199125)


--- trunk/Source/_javascript_Core/ChangeLog	2016-04-06 23:22:29 UTC (rev 199124)
+++ trunk/Source/_javascript_Core/ChangeLog	2016-04-07 00:13:51 UTC (rev 199125)
@@ -1,3 +1,17 @@
+2016-04-06  Geoffrey Garen  <[email protected]>
+
+        Unreviewed, rolling in r199016.
+        https://bugs.webkit.org/show_bug.cgi?id=156140
+
+        It might work this time without regression because 16kB aligned requests
+        now take the allocation fast path.
+
+        Restored changeset:
+
+        CopiedBlock should be 16kB
+        https://bugs.webkit.org/show_bug.cgi?id=156168
+        http://trac.webkit.org/changeset/199016
+
 2016-04-06  Mark Lam  <[email protected]>
 
         Update es6.yaml to expect es6/Proxy_internal_get_calls_RegExp_constructor.js to pass.

Modified: trunk/Source/_javascript_Core/heap/CopiedBlock.h (199124 => 199125)


--- trunk/Source/_javascript_Core/heap/CopiedBlock.h	2016-04-06 23:22:29 UTC (rev 199124)
+++ trunk/Source/_javascript_Core/heap/CopiedBlock.h	2016-04-07 00:13:51 UTC (rev 199125)
@@ -79,7 +79,7 @@
     size_t size();
     size_t capacity();
 
-    static const size_t blockSize = 32 * KB;
+    static const size_t blockSize = 16 * KB;
 
     bool hasWorkList();
     CopyWorkList& workList();
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to